@@ -193,8 +193,12 @@ class FileBackend(object) :
         except Exception, e :
             # delete the file in the event of an exception during saving
             # to protect from corrupted files causing problems later
-            _os.remove(self._get_filename(key))
-            raise
+            try :
+                _os.remove(self._get_filename(key))
+            except OSError :
+                pass
+            
+            raise e
     
     def _get_filename(self, key) :
         # hash the key and use as a filename
